<?php

namespace Wilsonwaldo\Sisep\Policies;

use Litepie\User\Contracts\UserPolicy;
use Wilsonwaldo\Sisep\Models\Enlaces;

class EnlacesPolicy
{

    /**
     * Determine if the given user can view the enlaces.
     *
     * @param UserPolicy $user
     * @param Enlaces $enlaces
     *
     * @return bool
     */
    public function view(UserPolicy $user, Enlaces $enlaces)
    {
        if ($user->canDo('sisep.enlaces.view') && $user->isAdmin()) {
            return true;
        }

        return $enlaces->user_id == user_id() && $enlaces->user_type == user_type();
    }

    /**
     * Determine if the given user can create a enlaces.
     *
     * @param UserPolicy $user
     * @param Enlaces $enlaces
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sisep.enlaces.create');
    }

    /**
     * Determine if the given user can update the given enlaces.
     *
     * @param UserPolicy $user
     * @param Enlaces $enlaces
     *
     * @return bool
     */
    public function update(UserPolicy $user, Enlaces $enlaces)
    {
        if ($user->canDo('sisep.enlaces.edit') && $user->isAdmin()) {
            return true;
        }

        return $enlaces->user_id == user_id() && $enlaces->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given enlaces.
     *
     * @param UserPolicy $user
     * @param Enlaces $enlaces
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Enlaces $enlaces)
    {
        return $enlaces->user_id == user_id() && $enlaces->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given enlaces.
     *
     * @param UserPolicy $user
     * @param Enlaces $enlaces
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Enlaces $enlaces)
    {
        if ($user->canDo('sisep.enlaces.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given enlaces.
     *
     * @param UserPolicy $user
     * @param Enlaces $enlaces
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Enlaces $enlaces)
    {
        if ($user->canDo('sisep.enlaces.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
